@@ -4,7 +4,10 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.164'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-20'; # DATE
+our $DIST = 'App-SerializeUtils'; # DIST
+our $VERSION = '0.165'; # VERSION
 
 1;
 # ABSTRACT: Utilities for serialization tasks
@@ -21,7 +24,7 @@ App::SerializeUtils - Utilities for serialization tasks
 
 =head1 VERSION
 
-This document describes version 0.164 of App::SerializeUtils (from Perl distribution App-SerializeUtils), released on 2021-04-22.
+This document describes version 0.165 of App::SerializeUtils (from Perl distribution App-SerializeUtils), released on 2022-03-20.
 
 =head1 SYNOPSIS
 
@@ -40,28 +43,12 @@ serialization:
 
 =item * L<check-yaml>
 
-=item * L<dd2dd>
-
-=item * L<dd2ddc>
-
-=item * L<dd2json>
-
-=item * L<dd2phpser>
-
-=item * L<dd2sereal>
-
-=item * L<dd2sexp>
-
-=item * L<dd2storable>
-
-=item * L<dd2yaml>
-
-=item * L<json2dd>
-
-=item * L<json2ddc>
-
 =item * L<json2json>
 
+=item * L<json2perl>
+
+=item * L<json2perlcolor>
+
 =item * L<json2phpser>
 
 =item * L<json2sereal>
@@ -72,12 +59,28 @@ serialization:
 
 =item * L<json2yaml>
 
-=item * L<phpser2dd>
+=item * L<perl2json>
 
-=item * L<phpser2ddc>
+=item * L<perl2perl>
+
+=item * L<perl2perlcolor>
+
+=item * L<perl2phpser>
+
+=item * L<perl2sereal>
+
+=item * L<perl2sexp>
+
+=item * L<perl2storable>
+
+=item * L<perl2yaml>
 
 =item * L<phpser2json>
 
+=item * L<phpser2perl>
+
+=item * L<phpser2perlcolor>
+
 =item * L<phpser2sereal>
 
 =item * L<phpser2sexp>
@@ -86,18 +89,18 @@ serialization:
 
 =item * L<phpser2yaml>
 
-=item * L<pp-dd>
-
 =item * L<pp-json>
 
+=item * L<pp-perl>
+
 =item * L<pp-yaml>
 
-=item * L<sereal2dd>
-
-=item * L<sereal2ddc>
-
 =item * L<sereal2json>
 
+=item * L<sereal2perl>
+
+=item * L<sereal2perlcolor>
+
 =item * L<sereal2phpser>
 
 =item * L<sereal2sexp>
@@ -108,12 +111,12 @@ serialization:
 
 =item * L<serializeutils-convert>
 
-=item * L<sexp2dd>
-
-=item * L<sexp2ddc>
-
 =item * L<sexp2json>
 
+=item * L<sexp2perl>
+
+=item * L<sexp2perlcolor>
+
 =item * L<sexp2phpser>
 
 =item * L<sexp2sereal>
@@ -122,12 +125,12 @@ serialization:
 
 =item * L<sexp2yaml>
 
-=item * L<storable2dd>
-
-=item * L<storable2ddc>
-
 =item * L<storable2json>
 
+=item * L<storable2perl>
+
+=item * L<storable2perlcolor>
+
 =item * L<storable2phpser>
 
 =item * L<storable2sereal>
@@ -136,12 +139,12 @@ serialization:
 
 =item * L<storable2yaml>
 
-=item * L<yaml2dd>
-
-=item * L<yaml2ddc>
-
 =item * L<yaml2json>
 
+=item * L<yaml2perl>
+
+=item * L<yaml2perlcolor>
+
 =item * L<yaml2phpser>
 
 =item * L<yaml2sereal>
@@ -162,14 +165,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Serial
 
 Source repository is at L<https://github.com/perlancar/perl-App-SerializeUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-SerializeUtils/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Data::Dump>
@@ -188,11 +183,42 @@ L<YAML>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018, 2017, 2015, 2014, 2013, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2020, 2018, 2017, 2015, 2014, 2013, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-SerializeUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
